#ifndef COMMON_CK
#define COMMON_CK

#include "WHRN.h"

namespace cmmn {



	double normal_0_to_z( double z );

	double Cum_NormalKC( double z );

	double PFPsi( double x, double mean, double sd );


	class Rec {
		public:
			int ixrec, irrec;
	};

	class Psi {
		public:
			double ** ptlambda;		//	prior at trial t,	lambda = (mean, sigma)
			double ** ptlambda0;		//	prior used in the final analysis
			double ** ptrx;			//	Pt(r|x)
			double **** ptl_xr;		//	Pt(lambda|x,r)
			double ** H;			//	Ht(x,r)
			double * EH;			//	Ht(x) = E(Ht(x,r))
			Rec * rec;
			int xt1, rt1, ipos;

			int NMean,				//	= 31;  No. of values of mean + 1
				NSigma,				//	= 51;  No. of values of sigma + 1
				NXValue,			//	= NMean;  No. of x values
				NTrial;				//	= 40;  No. of trials per series
			double  LMean,			//	The lowest value of mean
					LSigma,			//	The lowest value of sigma
					StdSt;			//	The standard stimulus

			Psi(): NMean(41), NSigma(101), LMean(80.0), LSigma(0.1), NTrial(40), StdSt(100.0) {
				NXValue = NMean;
				ptlambda = new double*[NMean];
				ptlambda0 = new double*[NMean];
				for (int i = 0; i < NMean; i++){
					ptlambda[i] = new double[NSigma];
					ptlambda0[i] = new double[NSigma];
				}
				ptrx = new double*[2];
				for (int i = 0; i < 2; i++)
					ptrx[i] = new double[NXValue];
				ptl_xr = new double***[NMean];
				for (int i = 0; i < NMean; i++){
					ptl_xr[i] = new double**[NSigma];
					for (int j = 0; j < NSigma; j++){
						ptl_xr[i][j] = new double*[NXValue];
						for (int k = 0; k < NXValue; k++)
							ptl_xr[i][j][k] = new double[2];
					}
				}
				H = new double*[NXValue];
				for (int i = 0; i < NXValue; i++)
					H[i] = new double[2];
				EH = new double[NXValue];
				rec = new Rec[NTrial];

				ipos = 0;

				for (int i = 0; i < NMean; i++)
					for (int j = 0; j < NSigma; j++)
						ptlambda0[i][j] = ptlambda[i][j] = 1.0 / (NMean * NSigma);
			}

			double Mean( int i ){
				return LMean + 1.0 * i;
			}
			double Sigma( int i ){
				return LSigma + i * 0.2;
			}
			double x_value( int i ){
				return Mean(i);
			}

			void Prepare();
			void CalcPost();
	};  //  Psi


	 extern Psi * psi1;
	 extern Psi * psi2;

	 extern double * PMean, * PSigma;
	 extern int imgx0, imgy0, imgyH, imgyL;
	 extern int * StSer;
	 extern int itrial;
	 extern Psi * VPsi;

	 using namespace MyLib;

	 extern WHrn RN;

}

#endif
